<?php
/**
 * Prompt Theme functions and definitions
 * 
 * @package Prompt
 * @since 1.0
 */


/**
 * Prompt Theme Constants
 * 
 * @since 1.0
 */
define('PROMPT_PRO', FALSE );
define('PROMPT_ASSETS_URL', get_template_directory_uri() . '/assets/');
define('PROMPT_GLOBAL_URL', PROMPT_ASSETS_URL . 'global/');
define('PROMPT_GLOBAL_JS_URL', PROMPT_ASSETS_URL . 'global/js/');
define('PROMPT_GLOBAL_IMAGES_URL', PROMPT_ASSETS_URL . 'global/images/');
define('PROMPT_GLOBAL_CSS_URL', PROMPT_ASSETS_URL . 'global/css/');
define('PROMPT_ADMIN_URL', PROMPT_ASSETS_URL . 'admin/');
define('PROMPT_INCLUDES_DIR' , get_template_directory() . '/includes/' );



/**
 * Prompt Theme Variables
 * 
 * @since 1.0
 */
$prompt_post_count = 1;
$prompt_sticky_count = 0;



/**
 * Options framework call
 */
require_once PROMPT_INCLUDES_DIR . 'customizer.php';



/**
 * Sets up theme defaults and registers support for various theme features
 * 
 * @since 1.0
 */
function prompt_setup() {
    
    global $content_width;
    
    /**
     * Primary content width according to the design and stylesheet.
     */
    if ( ! isset( $content_width ) ) { $content_width = 890; }
    
    /**
     * Makes prompt Theme ready for translation.
     * Translations can be filed in the /languages/ directory
     */
    load_theme_textdomain('prompt', get_template_directory() . '/languages');

    /**
     * Add default posts and comments RSS feed links to head.
     */
    add_theme_support('automatic-feed-links');
    
    /**
     * Add custom header.
     */
    add_theme_support('custom-header', array('default-image' => PROMPT_GLOBAL_IMAGES_URL . 'canada-lake.jpg', 'flex-height' => true, 'header-text' => false, 'uploads' => true, 'width' => 765, 'height' => 500));

    /**
     * Add custom background.
     * @todo Put E7E7E7 in a variable and then change it according to the skin
     */
    add_theme_support('custom-background', array('default-color' => 'E7E7E7'));
    
    /**
     * Add title-tag support
     */
    add_theme_support('title-tag');
    
    /**
     * Adds supports for Theme menu.
     * Prompt uses wp_nav_menu() in a single location to diaplay one single menu.
     */
    register_nav_menu('primary', 'Primary Menu');

    /**
     * Add support for Post Thumbnails.
     * Defines a custom name and size for Thumbnails to be used in the theme.
     *
     * Note: In order to use the default theme thumbnail, add_image_size() must be removed
     * and 'promptThumb' value must be removed from the_post_thumbnail in the loop file.
     */
    add_theme_support('post-thumbnails');
    add_image_size('promptThumb', 175, 150, true);
}
add_action( 'after_setup_theme', 'prompt_setup' );



/**
 * Defines menu values and call the menu itself.
 * The menu is registered using register_nav_menu function in the theme setup.
 * 
 * @since 1.0
 */
function prompt_nav() {
    wp_nav_menu(array(
        'theme_location' => 'primary',
        'container_id' => 'menu',
        'menu_class' => 'sf-menu prompt_menu',
        'menu_id' => 'prompt_menu',
        'fallback_cb' => 'prompt_nav_fallback' // Fallback function in case no menu item is defined.
    ));
}



/**
 * Displays a custom menu in case either no menu is selected or
 * menu does not contains any items or wp_nav_menu() is unavailable.
 * 
 * @since 1.0
 */
function prompt_nav_fallback() {
?>
    <div id="menu">
    	<ul class="sf-menu" id="prompt_menu">
			<?php
            	wp_list_pages( 'title_li=&sort_column=menu_order&depth=3');
            ?>
        </ul>
    </div>
<?php
}



/**
 * Register sidebars one at right and three footer sidebars in a box.
 * 
 * @since 1.0
 */
function prompt_sidebars() {

    // Footerbox Sidebar #1
    register_sidebar(array(
        'name' => __('Footerbox Sidebar #1', 'prompt'),
        'id' => 'footerbox_sidebar_1',
        'description' => __('Footerbox Sidebar #1', 'prompt'),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h4 class="widget-title">',
        'after_title' => '</h4>',
    ));
    
    // Footerbox Sidebar #2
    register_sidebar(array(
        'name' => __('Footerbox Sidebar #2', 'prompt'),
        'id' => 'footerbox_sidebar_2',
        'description' => __('Footerbox Sidebar #2', 'prompt'),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h4 class="widget-title">',
        'after_title' => '</h4>',
    ));
    
    // Footerbox Sidebar #3
    register_sidebar(array(
        'name' => __('Footerbox Sidebar #3', 'prompt'),
        'id' => 'footerbox_sidebar_3',
        'description' => __('Footerbox Sidebar #3', 'prompt'),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h4 class="widget-title">',
        'after_title' => '</h4>',
    ));
    
}
add_action( 'widgets_init', 'prompt_sidebars' );



/**
 * Enqueue CSS and JS files
 * 
 * @since 1.0
 */
function prompt_enqueue() {
    
    wp_enqueue_style('cognize-open-sans', '//fonts.googleapis.com/css?family=Open+Sans:400,300,300italic,400italic,600,700,600italic,700italic,800,800italic');
    wp_enqueue_style('prompt-stylesheet', get_stylesheet_uri(), false, '1.0.1', 'all' );
    wp_enqueue_style('prompt-font-awesome', PROMPT_ADMIN_CSS_URL . 'font-awesome.4.1.0.css');
    
    // Enqueue (comment-reply )Javascript in case of threaded comments.
    if (is_singular() && comments_open() && get_option('thread_comments')) :
        wp_enqueue_script('comment-reply');
    endif;
    
    wp_enqueue_script('prompt-flexslider', PROMPT_GLOBAL_JS_URL . 'jquery.flexslider-min.js', array( 'jquery' ), '2.1.0', true);
    wp_localize_script('prompt-flexslider', 'prompt_slide_vars', array(
                    'slideshowSpeed' => prompt_get_option('slide_speed'),
                    'animationSpeed' => prompt_get_option('slide_ani_speed'),
                    'directionNav' => (bool) prompt_get_option('disable_slide_nav') ? '' : 'true',
                    'smoothHeight' => (bool) prompt_get_option('disable_smooth_height') ? '' : 'true',
                    'animation' => prompt_get_option('slide_animation_type'),
                    'direction' => prompt_get_option('slide_dir'),
                    ));
    wp_enqueue_script('prompt-superfish', PROMPT_GLOBAL_JS_URL . 'superfish.min.js', array( 'jquery' ), '1.4.8', true);
    wp_enqueue_script('jquery-color');
    wp_enqueue_script('prompt-custom', PROMPT_GLOBAL_JS_URL . 'custom.min.js', array( 'jquery' ), '1.0.0', true);
}
add_action( 'wp_enqueue_scripts', 'prompt_enqueue');



/**
 * Hooks respond.js for IE in the wp_head hook.
 * 
 * @since 1.0
 */
function prompt_enqueue_ie_script() {
    echo "\n";
    ?><!--[if lt IE 9]><script type='text/javascript' src='<?php echo PROMPT_GLOBAL_JS_URL ?>respond.js'></script><![endif]--><?php
    echo "\n";
    ?><!--[if lt IE 9]><script type='text/javascript' src='<?php echo PROMPT_GLOBAL_JS_URL ?>html5shiv.min.js'></script><![endif]--><?php
    echo "\n";
}
add_action('wp_head', 'prompt_enqueue_ie_script');



/**
 * Defines the number of characters for post excerpts
 * and is added to excerpt_length filter.
 * 
 * @since 1.0
 */
function prompt_excerpt_length( $length ) {
	return 43;
}
add_filter( 'excerpt_length', 'prompt_excerpt_length' );



/**
 * Defines the text for the (read more) link for post excerpts
 * and is added to excerpt_more filter.
 * 
 * @since 1.0
 */
function prompt_auto_excerpt_more( $more ) {
	return '&hellip;' ;
}
add_filter( 'excerpt_more', 'prompt_auto_excerpt_more' );



/**
 * Loads any module required before loading templates.
 * 
 * @since 1.0
 */
function prompt_pre_load() {
    add_filter('body_class', 'prompt_body_class');
}



/**
 * Used to return body classes
 * 
 * @param array $classes
 * @return array
 * @since 1.0
 */
function prompt_body_class($classes) {
    
    if(is_single()):
        
        $classes[] = 'single-template';
        $classes[] = 'post-template';
    
    elseif(is_page()):
        
        $classes[] = 'page-template';
        $classes[] = 'post-template';

    elseif(is_front_page()):
        
        $classes[] = 'home-template';
    
    elseif(is_home()):
        
        $classes[] = 'home-template';
        $classes[] = 'blog-template';
    
    elseif (is_archive()):
        
        $classes[] = 'archive-template';
    
    elseif(is_404()):
        
        $classes[] = 'archive-template';
        $classes[] = 'empty-template';
    
    elseif(is_search()):
        
        $classes[] = 'archive-template';
        $classes[] = 'search-template';
    
    endif;
    
        $classes[] = 'white';
    
    return $classes;
}



/**
 * Displays carousel on the type of data stored in database
 * 
 * @return type
 */
function prompt_carousel_show() {
    
    if(prompt_get_option('carousel') == 'featured'):
        
        prompt_carousel_featured_img_show();
    
    elseif(prompt_get_option('carousel') == 'slideshow'):
        
        prompt_carousel_slideshow_img_show();
    
    else:
        
        return;
    
    endif;
}



/**
 * Displays featured image only if one exits
 * 
 * @since 1.0
 * @todo Check HTML structure and CSS classes.
 */
function prompt_carousel_featured_img_show(){
    
    if(get_header_image()):
        echo '<div class="carousel_section">';
        echo '<img class="carousel_featured_img" src="'.esc_url( get_header_image() ).'" />';
        echo '</div>';
    endif;
}



/**
 * Display slideshow only if any slideshow image exists.
 * 
 * @since 1.0
 * @todo Check HTML structure and CSS classes.
 */
function prompt_carousel_slideshow_img_show(){
    
    for($i = 1; $i <= 2; $i++){
        $slides[$i] = prompt_get_option('slide_img_' . $i);
    }
        
    $error = array_filter($slides); // Check if array is empty.
        
        if(!empty($error)): ?>
            <div id = "featured-container" class = "slider">
                <div class = "flexslider">
                    <ul class = "slides">
                        <?php
                            if(is_array($slides)):
                                foreach ($slides as $slides):
                                    if(!empty($slides)): 
                                        ?>
                                        <li>
                                            <img src="<?php echo esc_url( $slides ) ?>" />
                                        </li>
                                            <?php
                                    endif;
                                endforeach;
                            endif;
                            ?>
                        </ul>
                </div>
            </div>
        <?php endif;
}



/**
 * Used to display CTA section
 * 
 * @since 1.0
 */
function prompt_cta_section_show(){
    ?>
    <?php if(!prompt_get_option('disable_cta_section')): ?>
        <div id="cta-bg-section" class="cta-bg-section grid-col-16 clearfix">
            <div id="cta-section" class="cta-section grid-col-16 clearfix">
                <div id="cta-content-section" class="cta-content-section grid-col-12">
                    <div class="cta-content-heading"><span><?php echo esc_html( prompt_get_option('featured_heading') ) ?></span></div>
                    <div class="cta-content-text"><span><?php echo esc_html (prompt_get_option('featured_content') ) ?></span></div>
                    <div class="cta-image-section"><?php prompt_carousel_show() ?></div>
                    <?php if(!prompt_get_option('disable_cta_buttons')): ?>
                        <div class="cta-buttons clearfix">
                            <div class="cta-button-1 clearfix"><a title="<?php echo esc_attr(prompt_get_option('cta_button_1')) ?>" href="<?php echo esc_url(prompt_get_option('cta_button_url_1')) ?>"><?php if(!prompt_get_option('disable_cta_icons')){ ?><i class="mdf mdf-<?php echo esc_attr(prompt_get_option('cta_button_icon_1')) ?>"></i><?php } ?><?php echo esc_html(prompt_get_option('cta_button_1')) ?></a></div>
                            <div class="cta-button-2 clearfix"><a title="<?php echo esc_attr(prompt_get_option('cta_button_2')) ?>" href="<?php echo esc_url(prompt_get_option('cta_button_url_2')) ?>"><?php if(!prompt_get_option('disable_cta_icons')){ ?><i class="mdf mdf-<?php echo esc_attr(prompt_get_option('cta_button_icon_2')) ?>"></i><?php } ?><?php echo esc_html(prompt_get_option('cta_button_2')) ?></a></div>
                        </div>
                    <?php endif; ?>
                    <div class="cta-content-text-bottom"><span><?php echo esc_html(prompt_get_option('featured_content_bottom')) ?></span></div>
                </div>
            </div> <!-- cta section ends -->
        </div>
    <?php endif; ?>

<?php }



/**
 * Checks whether the all the content sections are disabled or not.
 * 
 * @since 1.0
 */
function prompt_is_home() {
    
    if(prompt_get_option('disable_cta_section') && (get_option('show_on_front') == 'posts')){
        add_filter('prompt_blog_template_heading_filter', 'prompt_is_blog_heading_text', 20);
        return TRUE;
    } else {
        return FALSE;
    }
}



/**
 * Adds text to prompt_blog_template_heading_filter used on home.php
 * 
 * @return string
 */
function prompt_is_blog_heading_text(){
    return '';
}



/**
 * Used to display social section
 * 
 * @since 1.0
 */
function prompt_social_section_show() {
    
    if(!prompt_get_option('disable_social_section')):

    $output = false;
    ?>            
                
                <?php if(prompt_get_option('facebook')): ?>
                <?php $output .= '
                <div class="social-icons">
                    <a href="'.esc_url(prompt_get_option('facebook')).'" title="Facebook Profile"><i class="mdf mdf-facebook"></i></a>
                </div>' ?>
                <?php endif ?>
                
                <?php if(prompt_get_option('twitter')): ?>
                <?php $output .= '
                <div class="social-icons">
                    <a href="'.esc_url(prompt_get_option('twitter')).'" title="Twitter Profile"><i class="mdf mdf-twitter"></i></a>
                </div>' ?>
                <?php endif ?>
                
                <?php if(prompt_get_option('rss')): ?>
                <?php $output .= '
                <div class="social-icons">
                    <a href="'.esc_url(prompt_get_option('rss')).'" title="RSS Feed"><i class="mdf mdf-rss"></i></a>
                </div>' ?>
                <?php endif ?>
                
                <?php if($output !== false): ?>
                <div id="social-section" class="social-section grid-col-16 clearfix">
                    <?php echo $output ?>
                </div>
                <?php endif ?>
            
            <div class="socialicons-mi"></div><div class="socialicons-mo"></div>

<?php
    endif;
}



/**
 * Displays the content in case of 404 page, empty search query
 * and any other query which does not output any result.
 * 
 * Both heading and content of the page will be displayed with a
 * search form. Any modification to this module will effect only
 * 404 error or related pages.
 * 
 * @since 1.0
 */
function prompt_404_show(){
?>
        <div class="archive-meta-container">
            <div class="archive-head">
                <?php if (is_404()) : ?>
                    <h1><?php _e('Ooops! Nothing Found', 'prompt'); ?></h1>
                <?php elseif (is_search()) : ?>
                    <h1><?php printf(__('Nothing found for: %s', 'prompt'), get_search_query()); ?></h1>
                <?php else : ?>
                    <h1><?php printf(__('Nothing found for: %s', 'prompt'), single_term_title('', false)); ?></h1>
                <?php endif; ?>
            </div>
        </div><!-- Archive Meta Container ends -->
        
        <div class="archive-loop-container archive-empty">
            <div class="archive-excerpt">
                <p><?php _e('Apologies, but no results were found for the requested archive. Perhaps searching will help find a related post.', 'prompt'); ?></p>
                <?php get_search_form(); ?>
            </div>
        </div>
<?php }



/**
 * Decides and returns the accurate 'text' to be displayed.
 * 
 * @return string
 * @since 1.0
 */
function prompt_date_text() {
    if (is_date()):
        if (is_day()):
            $date_text = __('Day', 'prompt');
        elseif (is_month()):
            $date_text = __('Month', 'prompt');
        elseif (is_year()):
            $date_text = __('Year', 'prompt');
        else:
            $date_text = __('Period', 'prompt');
        endif;

        return $date_text;

    endif;
}



/**
 * Displays the navigation links for the archive pages. Is only
 * applicable if the total number of pages is more than 'one'.
 * 
 * @since 1.0
 */
function prompt_archive_nav() {
    
    global $wp_query;

    if ($wp_query->max_num_pages > 1): ?>
        
        <div class="archive-nav grid-col-16">
            <div class="nav-next"><?php previous_posts_link(__('<span class="meta-nav">&larr;</span> Newer posts', 'prompt')); ?></div>
            <div class="nav-previous"><?php next_posts_link(__('Older posts <span class="meta-nav">&rarr;</span>', 'prompt')); ?></div>
        </div>
        
<?php endif;
}



/**
 * Displays the navigation links for the posts and pages.
 * 
 * @since 1.0
 */
function prompt_post_nav() {
?>
    <div class="post-nav">
        <div class="nav-previous"><?php previous_post_link( '%link', '%title <span class="meta-nav">' . _x( '&rarr;', 'Previous post link', 'prompt' ) . '</span>' ) ?></div>
        <div class="nav-next"><?php next_post_link( '%link', '<span class="meta-nav">' . _x( '&larr;', 'Next post link', 'prompt' ) . '</span> %title' ) ?></div>
    </div>
<?php
}



/**
 * Display site title/description or logo
 * 
 * @since 1.0
 */
function prompt_logo() {
    $logo_img = prompt_get_option('logo_img');

        if( empty($logo_img)): ?>
        
        <div id="site-title" class="site-title">
                <a href="<?php echo esc_url( home_url( '/' ) ) ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ) . ' | ' . esc_attr( get_bloginfo('description') ) ?>" rel="home"><?php echo esc_html(get_bloginfo( 'name', 'display' )) ?></a>
            </div>
            <?php if(!prompt_get_option('disable_site_desc')): ?>
                <div id="site-description" class="site-description"><?php echo esc_html( get_bloginfo( 'description' ) ) ?></div>
            <?php endif; ?>
        <?php else: ?>
        
            <div id="site-title">
                <a href="<?php echo esc_url( home_url( '/' ) ) ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ) ?>" rel="home"><img src="<?php echo esc_url( prompt_get_option('logo_img') ) ?>"/></a>
            </div>

        <?php endif;
}



/**
 * Template for comments and pingbacks.
 * 
 * @since 1.0
 */
function prompt_comment_callback( $comment, $args, $depth ) {

  $GLOBALS['comment'] = $comment;
  switch ( $comment->comment_type ):

         case '' :
		 // Proceed with normal comments.
  ?>
  <li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
        <?php if ($comment->comment_approved == '0') : ?><div class="comment-awaiting"><em class="comment-awaiting-moderation"><?php _e('Your comment is awaiting moderation.', 'prompt'); ?></em></div><?php endif; ?>
        <?php $cognize_get_comment_ID = get_comment_ID() ?>
        <?php $cognize_is_comment_reply = get_comment($cognize_get_comment_ID)->comment_parent ?>
        <?php $cognize_the_comment_author = get_comment_author(get_comment($cognize_get_comment_ID)->comment_parent) ?>
        <?php if($cognize_is_comment_reply != 0 ) printf('<div class="comment-parent-author"><span>Replied to %s</span></div>', $cognize_the_comment_author ) ?>
      <div id="comment-<?php comment_ID(); ?>" class="comment-block-container grid-float-left grid-col-16">
          
          
                     <div class="comment-info-container grid-col-4 grid-float-left">
                          <div class="comment-author vcard">
                              <div class="comment-author-avatar-container"><?php echo get_avatar($comment, 100); ?></div>
                              <div class="comment-author-info-container">
                                  <div class="comment-author-name"><?php printf(__('%s <span class="says"></span>', 'prompt'), sprintf('<cite class="fn">%s</cite>', get_comment_author_link())) ?></div>
                              </div>
                          </div><!-- .comment-author .vcard -->
                     </div>
          
                     <div class="comment-body-container grid-col-12 grid-float-left">
                        <div class="comment-body"><?php comment_text(); ?></div>
                        <div class="comment-meta commentmetadata"><a href="<?php echo esc_url(get_comment_link($comment->comment_ID)); ?>"><?php printf(__('%1$s at %2$s', 'prompt'), get_comment_date(), get_comment_time()); ?></a></div>
                        <div class="reply"><?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?></div>
                        <?php edit_comment_link(__('(Edit)', 'prompt'), '<div class="comment-edit">', '</div>');?>
                     </div>

      </div><!-- #comment-##  -->

<?php
         break;

         case 'pingback' :
         case 'trackback' :
		 // Display trackbacks differently than normal comments.
  ?>

  <li class="post pingback">
      <p><?php _e( 'Pingback:', 'prompt' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( '(Edit)', 'prompt' ), ' ' ); ?></p>

  <?php
         break;

  endswitch;
}



/**
 * Adds text to prompt_readmore_text_filter
 * 
 * @return string
 * @since 1.0
 */
function prompt_readmore_text() {
    return __('Read more', 'prompt');
}
add_filter('prompt_readmore_text_filter', 'prompt_readmore_text', 10);



/**
 * Adds text to prompt_blog_template_heading_filter used on home.php
 * 
 * @return string
 * @since 1.0
 */
function prompt_blog_template_heading_text() {
    return '<h1>' . get_bloginfo('name') . ' ' . __('Blog', 'prompt') . '</h1>';
}
add_filter('prompt_blog_template_heading_filter', 'prompt_blog_template_heading_text', 10);